# TaxRateType

Enum:\"Percentage\" \"FlatFee\". The type of the tax rate applied to the invoice.

## Enum

* `PERCENTAGE` (value: `'Percentage'`)

* `FLATFEE` (value: `'FlatFee'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


